@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 """
-    shake_auth.auth
-    ----------------------------------------------
+    # shake_auth.auth
+
     
-    :Copyright © 2010-2011 by Lúcuma labs (http://lucumalabs.com).
-    :MIT License. (http://www.opensource.org/licenses/mit-license.php)
+    --------
+    Copyright © 2010–2011 by Lúcuma labs (http://lucumalabs.com).
+
+    MIT License. (http://www.opensource.org/licenses/mit-license.php)
 
 """
 from datetime import datetime
@@ -302,6 +304,9 @@ class Auth(object):
                 return self._token_authentication(token)
     
     def _loginpass_authentication(self, login, password, update):
+        # iOS by default makes you write the first letter as uppercase.
+        # The username should be case insensitive anyway.
+        login = login.lower()
         user = self.db.query(self.User) \
             .filter(self.User.login == login).first()
         if not user:
@@ -424,6 +429,9 @@ class Auth(object):
     def create_user(self, login, passw, **data):
         """[-login] USER_NAME [-passw] PASSWORD
         Creates a new user."""
+        # iOS by default makes you write the first letter as uppercase.
+        # The username should be case insensitive anyway.
+        login = login.lower()
         user_exists = self.db.query(self.User) \
             .filter(self.User.login == login).count()
         if user_exists:
@@ -441,6 +449,9 @@ class Auth(object):
     def change_password(self, login, passw):
         """[-login] USER_NAME [-passw] NEW_PASSWORD
         Changes the password of an existing user."""
+        # iOS by default makes you write the first letter as uppercase.
+        # The username should be case insensitive anyway.
+        login = login.lower()
         user = self.db.query(self.User) \
             .filter(self.User.login == login).first()
         if not user:
@@ -529,6 +540,9 @@ class Auth(object):
         # Phase 2
         elif request.is_post:
             login = request.form.get('login')
+            # iOS by default makes you write the first letter as uppercase.
+            # The username should be case insensitive anyway.
+            login = login.lower()
             user = self.db.query(self.User) \
                 .filter(self.User.login == login).first()
             if not user:
