@@ -1,55 +1,46 @@
 # -*- coding: utf-8 -*-
 """
-    shake_auth.perms
-    ----------------------------------------------
-    
+    # shake_auth.perms
+
     Permission system & Cross Site Request Forgery protection.
-    
-    This extension provides easy-to-use protection against
-    `Cross Site Request Forgeries`_.  This type of attack occurs when a
-    malicious web site creates a link or form button that is intended to
-    perform some action on your Web site, using the credentials of a
-    logged-in user who is tricked into clicking on the link in their browser.
+
+    This extension provides easy-to-use protection against [Cross Site
+    Request Forgeries][]. This type of attack occurs when a malicious web
+    site creates a link or form button that is intended to perform some
+    action on your Web site, using the credentials of a logged-in user who
+    is tricked into clicking on the link in their browser.
+
+        [Cross Site Request Forgeries]: http://en.wikipedia.org/wiki/Cross-site_request_forgery
     
     The first defense against CSRF attacks is to ensure that GET requests
-    are side-effect free.  POST requests can then be protected by adding a
+    are side-effect free. POST requests can then be protected by adding a
     unique value as hidden input in your forms.
-    
-    .. note::
-        
-        This is intended to use on POST requests that can only be made
-        accompanied by a session cookie. Any other requests do not need to
-        be protected, since the 'attacking' Web site could make those requests
-        anyway.
-    
-    .. _Cross Site Request Forgeries:
-        http://en.wikipedia.org/wiki/Cross-site_request_forgery
-    
-    # How to Use
-    
+
+    ## How to Use
+
     1.  In any view that uses a POST form, use the csrf_secret global
-        variable inside the <form> element if the form is for an internal
+        variable inside the <form\> element if the form is for an internal
         URL, e.g.:
-            
+
             <form action="" method="post">
-            ...
-            {{ csrf_secret.input }}
+                …
+                {{ csrf_secret.input }}
             </form>
-        
+
         This should *not* be done for POST forms that target external URLs,
         since that would cause the CSRF secret to be leaked, leading to a
         vulnerability.
-    
+
     2.  If the corresponding view function is decorated with
-        :func:`ext.perms.protected` the csrf secret will be automatically
+        `ext.perms.protected` the csrf secret will be automatically
         checked. If no csrf secret is found or its value is incorrect, the
         decorator will raise a :class:`shake.NotAllowed` error.
-        
-        If you aren't using the decorator or prefer to do the check manually,
-        you can disable this feature by passing a csrf=False argument to
-        the decorator, and using :func:ext.auth.invalid_csrf_secret to
-        validate the secret, e.g.:
-            
+
+        If you aren’t using the decorator or prefer to do the check
+        manually, you can disable this feature by passing a csrf=False
+        argument to the decorator, and using the function 'invalid_csrf_secret'
+        to validate the secret, e.g.:
+
             from shake import NotAllowed
             from shake_auth import protected, invalid_csrf_secret
             
@@ -59,35 +50,32 @@
                     raise NotAllowed()
                 ...
     
-    # AJAX
-    
-    To use the CSRF protection with AJAX calls insert the secret in
-    your HTML view, as a javascript variable, and read it later
-    from your script, e.g.:
-        
+    ## AJAX
+
+    To use the CSRF protection with AJAX calls insert the secret in your
+    HTML view, as a javascript variable, and read it later from your script,
+    e.g.:
+
         <script>
         var CSRF_TOKEN = '{{ csrf_secret.value }}';
         </script>
-        
-        ... later, in your javascript code::
-        
-        $.post('/theurl', {
-            'something': something,
-            ...
-            
-            '_csrf': CSRF_TOKEN
-            });
-
+    
+    and later, in your javascript code:
+    
+        $.post(‘/theurl’, {
+            … your data …
+           '_csrf': CSRF_TOKEN
+        });
     
     Additionally, Shake-Auth accept the CSRF token in the custom HTTP header
-    X-CSRFToken, as well as in the form submission itself, for ease of use with
-    popular JavaScript toolkits which allow insertion of custom headers into
-    all AJAX requests.
-    
+    X-CSRFToken, as well as in the form submission itself, for ease of use
+    with popular JavaScript toolkits which allow insertion of custom headers
+    into all AJAX requests.
+
     The following example using the jQuery JavaScript toolkit demonstrates
-    this; the call to jQuery's ajaxSetup will cause all AJAX requests to send
-    back the CSRF token in the custom X-CSRFTOKEN header:
-        
+    this; the call to jQuery’s ajaxSetup will cause all AJAX requests to
+    send back the CSRF token in the custom X-CSRFTOKEN header:
+
         $.ajaxSetup({
             beforeSend: function(xhr, settings) {
                 var isAbsoluteUrl = /^[a-z0-9]+:\/\/.*/.test(settings.url);
@@ -98,8 +86,11 @@
             }
         });
     
-    :Copyright © 2010-2011 by Lúcuma labs (http://lucumalabs.com).
-    :MIT License. (http://www.opensource.org/licenses/mit-license.php)
+    
+    --------
+    Copyright © 2010–2011 by Lúcuma labs (http://lucumalabs.com).
+
+    MIT License. (http://www.opensource.org/licenses/mit-license.php)
 
 """
 from shake import redirect, NotAllowed, url_for, get_csrf_secret
